#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
%define		certname	local_cert
%define		dhname		local_dh
%define		enginesvers	3

#-----------------------------------------------------------------------------
Name		:	openssl
Version		:	3.3.2
Release		:	17.0.10.rel%{?dist}
Summary		:	Tools for searching and reading man pages
Group		:	System Environment/Libraries

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	OpenSSL
URL		:	http://www.openssl.org/
			#https://github.com/openssl/

Source0		:	%{name}-%{version}.tar.gz
Source1		:	%{name}-ok_addon.tar.gz
 
#-----------------------------------------------------------------------------
BuildRequires	:	gcc
BuildRequires	:	gcc-c++
BuildRequires	:	coreutils
BuildRequires	:	perl
BuildRequires	:	sed
BuildRequires	:	zlib-devel

Requires(post)	:	bash
Requires(post)	:	coreutils
Requires(post)	:	inetutils
Requires(post)	:	make-ca

Requires	:	%{name}-libs = %{version}-%{release}
#-----------------------------------------------------------------------------
%description
The OpenSSL toolkit provides support for secure communications between
machines. OpenSSL includes a certificate management tool and shared
libraries which provide various cryptographic algorithms and
protocols.

#-----------------------------------------------------------------------------
%files			
%defattr(-,root,root,-)
%doc CHANGES.md NEWS.md README.md
%license LICENSE.txt
%{_bindir}/make_dummy_cert
%{_bindir}/%{name}
%{_mandir}/man1/*.1_ssl.gz
%{_mandir}/man5/*.5_ssl.gz
%{_mandir}/man7/*.7_ssl.gz
%{_defaultdocdir}/%{name}-%{version}/html/man1/*.html
%{_defaultdocdir}/%{name}-%{version}/html/man5/*.html
%{_defaultdocdir}/%{name}-%{version}/html/man7/*.html
%{_defaultdocdir}/%{name}-%{version}/html/man7/img/*.png

%post
if [ ! -L %{_sysconfdir}/pki/tls/private/%{certname} -a -n "`hostname`" ] ; then
  %{_bindir}/make_dummy_cert %{_sysconfdir}/pki/tls/private/dummyselfsigned.pem
  ln -s ./dummyselfsigned.pem %{_sysconfdir}/pki/tls/private/%{certname}
  ln -s ./dh-ok-release-4096 %{_sysconfdir}/pki/tls/private/%{dhname}
  fi
exit 0

#=============================================================================
%package		libs
Summary		:	A general purpose cryptography library with TLS implementation

	
#-----------------------------------------------------------------------------
%description		libs
OpenSSL is a toolkit for supporting cryptography. The openssl-libs
package contains the libraries that are used by various applications which
support cryptographic algorithms and protocols.
 

#-----------------------------------------------------------------------------
%files			libs
%defattr(-,root,root,-)
%license LICENSE.txt
%{_sysconfdir}/pki/tls/private/dh-ok-release-4096
%config(noreplace) %{_sysconfdir}/pki/tls/%{name}.cnf
%config(noreplace) %{_sysconfdir}/pki/tls/ct_log_list.cnf
%{_libdir}/engines-%{enginesvers}/*.so
%{_libdir}/libcrypto.so.*
%{_libdir}/libssl.so.*
%attr(0755,root,root) %{_libdir}/ossl-modules/legacy.so

#=============================================================================
%package		perl
Summary		:	Perl scripts provided with OpenSSL

#-----------------------------------------------------------------------------
Requires	:	perl	
Requires	:	%{name}	=  %{version}-%{release}

#-----------------------------------------------------------------------------
%description		perl
OpenSSL is a toolkit for supporting cryptography. The openssl-perl
package provides Perl scripts for converting certificates and keys
from other formats to the formats used by the OpenSSL toolkit.
 
#-----------------------------------------------------------------------------
%files			perl
%defattr(-,root,root,-)
%{_bindir}/c_rehash
%{_bindir}/*.pl
%{_bindir}/tsget

#=============================================================================
%package		devel
Summary		:	Files for development of applications which will use OpenSSL

	
#-----------------------------------------------------------------------------
Requires	:	%{name}-libs = %{version}-%{release}

#-----------------------------------------------------------------------------
%description		devel
OpenSSL is a toolkit for supporting cryptography. The openssl-devel
package contains include files needed to develop applications which
support various cryptographic algorithms and protocols.

#-----------------------------------------------------------------------------
%files			devel
%defattr(-,root,root,-)
%{_includedir}/%{name}/*.h
%{_libdir}/lib*.so
%{_libdir}/cmake/OpenSSL/OpenSSLConfig*.cmake
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3_ssl.gz
%{_defaultdocdir}/%{name}-%{version}/html/man3/*.html

#=============================================================================
%prep
%setup -q -n %{name}-%{version}
tar xf %{SOURCE1}

#-----------------------------------------------------------------------------
#building application
%build

./config						\
        --prefix=%{_prefix}				\
	--openssldir=%{_sysconfdir}/pki/tls		\
	--libdir=%{_libdir}				\
	shared						\
	zlib-dynamic					\
	enable-md2					\


%define _smp_mflags -j%(/usr/bin/getconf _NPROCESSORS_ONLN)
%{__make} depend
%{__make} %{_smp_mflags}

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
%check
HARNESS_JOBS=%(/usr/bin/getconf _NPROCESSORS_ONLN) %{__make} test

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

sed -i							\
  -e '/INSTALL_LIBS/s/libcrypto.a libssl.a//'		\
  Makefile

%{__make}						\
	DESTDIR=%{buildroot}				\
	MANSUFFIX=_ssl					\
	MANDIR=%{_mandir}				\
	install

%{__make}						\
	DESTDIR=%{buildroot}				\
	MANSUFFIX=_ssl					\
	MANDIR=%{_mandir}				\
	install_docs

pushd %{buildroot}%{_sysconfdir}/pki/tls
%{__rm}							\
	openssl.cnf.dist				\
	ct_log_list.cnf.dist
popd


%{__mv}							\
	%{buildroot}%{_defaultdocdir}/%{name}		\
	%{buildroot}%{_defaultdocdir}/%{name}-%{version}

# Move runable perl scripts to bindir
%{__mv}							\
	%{buildroot}%{_sysconfdir}/pki/tls/misc/*.pl	\
	%{buildroot}%{_sysconfdir}/pki/tls/misc/tsget	\
	%{buildroot}%{_bindir}
	
cp -a							\
	%{name}-ok_addon/make_dummy_cert		\
	%{buildroot}%{_bindir}

cp -a							\
	%{name}-ok_addon/dh-ok-release-4096		\
	%{buildroot}%{_sysconfdir}/pki/tls/private

#-----------------------------------------------------------------------------
%changelog
